## 1. Outbound HTTP clients

- [x] 1.1 Make shared `aiohttp` client initialization honor environment proxy settings
- [x] 1.2 Make Codex version GitHub lookups honor environment proxy settings
- [x] 1.3 Add regression coverage for outbound proxy-aware client setup

## 2. Database enum compatibility

- [x] 2.1 Align ORM enum declarations with persisted lowercase string values
- [x] 2.2 Add regression coverage for ORM enum value mapping

## 3. Spec sync

- [x] 3.1 Add outbound HTTP proxy behavior to the main specs
- [x] 3.2 Add database enum compatibility behavior to the main specs
